## Cryptocurrencies.AI API python client

Almost zero-dependency client: add https://pypi.org/project/six/ to requirements

Just copy ccai/client.py into your project and you are ready to go

More examples coming soon!

### How to generate api key and keyId?

Go to your profile api page: https://app.cryptocurrencies.ai/profile/api <br/>
Click on "GENERATE API KEY" <br/>
How to copy KeyId: <br/>
Go to your profile accounts page: https://app.cryptocurrencies.ai/profile/accounts <br/>
Click on copy icon -> your key token will be copied in clipboard
